.. _swh-objstorage:

Software Heritage - Object storage
==================================

Content-addressable object storage.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   cli
   winery
   /apidoc/swh.objstorage
